from .processor import ProcessorBase


class Sink(ProcessorBase):
	"""
	Description:

	:return:
	"""
	pass
